summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTim Smith <tsmith84@gmail.com>2020-04-30 15:45:01 -0700
committerTim Smith <tsmith84@gmail.com>2020-04-30 15:45:01 -0700
commitdaacd3b8ba731755c5cb3fdb683194fce6a01f62 (patch)
tree407820065357614229ef6b3de5c22e4d299fe16e
parent015b9fe8e4b0927fc9cb629c9cdaf434bbf1fac9 (diff)
downloadchef-daacd3b8ba731755c5cb3fdb683194fce6a01f62.tar.gz
OS X -> macOS
Signed-off-by: Tim Smith <tsmith@chef.io>
-rw-r--r--chef-config/lib/chef-config/path_helper.rb2
-rw-r--r--lib/chef/knife/supermarket_install.rb2
-rw-r--r--lib/chef/provider/user/dscl.rb2
-rw-r--r--lib/chef/resource/dmg_package.rb2
-rw-r--r--lib/chef/scan_access_control.rb2
-rw-r--r--omnibus/README.md2
-rw-r--r--spec/functional/resource/link_spec.rb6
-rw-r--r--spec/unit/file_access_control_spec.rb2
8 files changed, 10 insertions, 10 deletions
diff --git a/chef-config/lib/chef-config/path_helper.rb b/chef-config/lib/chef-config/path_helper.rb
index 2120a83bf6..341f6f583e 100644
--- a/chef-config/lib/chef-config/path_helper.rb
+++ b/chef-config/lib/chef-config/path_helper.rb
@@ -282,7 +282,7 @@ module ChefConfig
end
end
- # Determine if the given path is on the exception list for OS X System Integrity Protection.
+ # Determine if the given path is on the exception list for macOS System Integrity Protection.
def self.writable_sip_path?(path)
# todo: parse rootless.conf for this?
sip_exceptions = [
diff --git a/lib/chef/knife/supermarket_install.rb b/lib/chef/knife/supermarket_install.rb
index 55b32a1774..a3d3aa7a5d 100644
--- a/lib/chef/knife/supermarket_install.rb
+++ b/lib/chef/knife/supermarket_install.rb
@@ -96,7 +96,7 @@ class Chef
extract_cookbook(upstream_file, downloader.version)
# TODO: it'd be better to store these outside the cookbook repo and
- # keep them around, e.g., in ~/Library/Caches on OS X.
+ # keep them around, e.g., in ~/Library/Caches on macOS.
ui.info("Removing downloaded tarball")
File.unlink(upstream_file)
diff --git a/lib/chef/provider/user/dscl.rb b/lib/chef/provider/user/dscl.rb
index 34c5e82d45..39faa3d45c 100644
--- a/lib/chef/provider/user/dscl.rb
+++ b/lib/chef/provider/user/dscl.rb
@@ -28,7 +28,7 @@ class Chef
class User
#
# The most tricky bit of this provider is the way it deals with user passwords.
- # Mac OS X has different password shadow calculations based on the version.
+ # macOS has different password shadow calculations based on the version.
# < 10.7 => password shadow calculation format SALTED-SHA1
# => stored in: /var/db/shadow/hash/#{guid}
# => shadow binary length 68 bytes
diff --git a/lib/chef/resource/dmg_package.rb b/lib/chef/resource/dmg_package.rb
index 357da972e8..37382dd621 100644
--- a/lib/chef/resource/dmg_package.rb
+++ b/lib/chef/resource/dmg_package.rb
@@ -24,7 +24,7 @@ class Chef
provides(:dmg_package) { true }
- description "Use the **dmg_package** resource to install a package from a .dmg file. The resource will retrieve the dmg file from a remote URL, mount it using OS X's hdidutil, copy the application (.app directory) to the specified destination (/Applications), and detach the image using hdiutil. The dmg file will be stored in the Chef::Config[:file_cache_path]."
+ description "Use the **dmg_package** resource to install a package from a .dmg file. The resource will retrieve the dmg file from a remote URL, mount it using macOS' `hdidutil`, copy the application (.app directory) to the specified destination (`/Applications`), and detach the image using `hdiutil`. The dmg file will be stored in the `Chef::Config[:file_cache_path]``."
introduced "14.0"
examples <<~DOC
**Install Google Chrome via the DMG package**:
diff --git a/lib/chef/scan_access_control.rb b/lib/chef/scan_access_control.rb
index 0e99832400..d81166c28a 100644
--- a/lib/chef/scan_access_control.rb
+++ b/lib/chef/scan_access_control.rb
@@ -33,7 +33,7 @@ class Chef
# Not yet sure if this is the optimal way to solve the problem. But it's
# progress towards the end goal.
#
- # TODO: figure out if all this works with OS X's negative uids
+ # TODO: figure out if all this works with macOS' negative uids
# TODO: windows
class ScanAccessControl
diff --git a/omnibus/README.md b/omnibus/README.md
index 66bdb55448..6e49f091a5 100644
--- a/omnibus/README.md
+++ b/omnibus/README.md
@@ -24,7 +24,7 @@ You create a platform-specific package using the `build project` command:
$ bundle exec omnibus build <PROJECT>
```
-The platform/architecture type of the package created will match the platform where the `build project` command is invoked. For example, running this command on a MacBook Pro will generate a Mac OS X package. After the build completes packages will be available in the `pkg/` folder.
+The platform/architecture type of the package created will match the platform where the `build project` command is invoked. For example, running this command on a MacBook Pro will generate a macOS package. After the build completes packages will be available in the `pkg/` folder.
### Clean
diff --git a/spec/unit/file_access_control_spec.rb b/spec/unit/file_access_control_spec.rb
index f1f9cc9ec7..18983e6ff5 100644
--- a/spec/unit/file_access_control_spec.rb
+++ b/spec/unit/file_access_control_spec.rb
@@ -93,7 +93,7 @@ describe Chef::FileAccessControl do
end
it "wraps uids to their negative complements to correctly handle negative uids" do
- # More: Mac OS X (at least) has negative UIDs for 'nobody' and some other
+ # More: macOS (at least) has negative UIDs for 'nobody' and some other
# users. Ruby doesn't believe in negative UIDs so you get the diminished radix
# complement (i.e., it wraps around the maximum size of C unsigned int) of these
# uids. So we have to get ruby and negative uids to smoke the peace pipe
diff --git a/spec/functional/resource/link_spec.rb b/spec/functional/resource/link_spec.rb
index 7f527cfb60..24a1f5cd7b 100644
--- a/spec/functional/resource/link_spec.rb
+++ b/spec/functional/resource/link_spec.rb
@@ -656,10 +656,10 @@ describe Chef::Resource::Link do
end
context "and the link does not yet exist" do
it "links to the target file" do
- skip("OS X/FreeBSD/AIX/Solaris symlink? and readlink working on hard links to symlinks") if os_x? || freebsd? || aix? || solaris?
+ skip("macOS/FreeBSD/AIX/Solaris symlink? and readlink working on hard links to symlinks") if os_x? || freebsd? || aix? || solaris?
resource.run_action(:create)
expect(File.exists?(target_file)).to be_truthy
# OS X gets angry about this sort of link. Bug in OS X, IMO.
expect(symlink?(target_file)).to be_truthy
expect(readlink(target_file)).to eq(canonicalize(@other_target))
end
@@ -675,7 +675,7 @@ describe Chef::Resource::Link do
end
context "and the link does not yet exist" do
it "links to the target file" do
- skip("OS X/FreeBSD/AIX/Solaris fails to create hardlinks to broken symlinks") if os_x? || freebsd? || aix? || solaris?
+ skip("macOS/FreeBSD/AIX/Solaris fails to create hardlinks to broken symlinks") if os_x? || freebsd? || aix? || solaris?
resource.run_action(:create)
expect(File.exists?(target_file) || File.symlink?(target_file)).to be_truthy
expect(symlink?(target_file)).to be_truthy
@@ -656,10 +656,10 @@ describe Chef::Resource::Link do
resource.run_action(:create)
expect(File.exists?(target_file)).to be_truthy
- # OS X gets angry about this sort of link. Bug in OS X, IMO.
+ # macOS gets angry about this sort of link. Bug in macOS, IMO.
expect(symlink?(target_file)).to be_truthy
expect(readlink(target_file)).to eq(canonicalize(@other_target))